diff --git a/inc/auth/basic.class.php b/inc/auth/basic.class.php
index 79fb04a1c4a18a3c61f5b4f170a7800c15aa0712..077b92d62b854ea1d7374bed2ce7f0a8b2b12867 100644
--- a/inc/auth/basic.class.php
+++ b/inc/auth/basic.class.php
@@ -189,7 +189,7 @@ class auth_basic {
    * Create a new User [implement only where required/possible]
    *
    * Returns false if the user already exists, null when an error
-   * occured and true if everything went well.
+   * occurred and true if everything went well.
    *
    * The new user HAS TO be added to the default group by this
    * function!
diff --git a/inc/auth/mysql.class.php b/inc/auth/mysql.class.php
index 05ef828ce4f0e226d9d14b0f9c063cd7064aa483..9bb9fa1dfc2b946c98a129cd3978f480e0809ad4 100644
--- a/inc/auth/mysql.class.php
+++ b/inc/auth/mysql.class.php
@@ -170,7 +170,7 @@ class auth_mysql extends auth_basic {
      * [public function]
      *
      * Create a new User. Returns false if the user already exists,
-     * null when an error occured and true if everything went well.
+     * null when an error occurred and true if everything went well.
      *
      * The new user will be added to the default group by this
      * function if grps are not specified (default behaviour).
diff --git a/inc/auth/plain.class.php b/inc/auth/plain.class.php
index 156e2e5c8346035b2190bcf6559e2d7f4886d895..319bdbe02ed07faf07f2b321811c4dd13778ca0f 100644
--- a/inc/auth/plain.class.php
+++ b/inc/auth/plain.class.php
@@ -92,7 +92,7 @@ class auth_plain extends auth_basic {
      * Create a new User
      *
      * Returns false if the user already exists, null when an error
-     * occured and true if everything went well.
+     * occurred and true if everything went well.
      *
      * The new user will be added to the default group by this
      * function if grps are not specified (default behaviour).
diff --git a/inc/indexer.php b/inc/indexer.php
index c2f7d67790754c29fafc42ac85b8a837d4da3fb2..319e2b6e4be4892a188e2272def43a2dac0974e5 100644
--- a/inc/indexer.php
+++ b/inc/indexer.php
@@ -104,7 +104,7 @@ function idx_touchIndex($pre, $wlen){
 /**
  * Split a page into words
  *
- * Returns an array of word counts, false if an error occured.
+ * Returns an array of word counts, false if an error occurred.
  * Array is keyed on the word length, then the word index.
  *
  * @author Andreas Gohr <andi@splitbrain.org>
diff --git a/inc/lang/en/lang.php b/inc/lang/en/lang.php
index cd1720ff63fca3810fbbc3e14f7f8e010f64b900..f8558621f59e73aaec18cf1405fa6aa30e68f4c6 100644
--- a/inc/lang/en/lang.php
+++ b/inc/lang/en/lang.php
@@ -95,7 +95,7 @@ $lang['lockexpire']   = 'Lock expires at';
 $lang['willexpire']   = 'Your lock for editing this page is about to expire in a minute.\nTo avoid conflicts use the preview button to reset the locktimer.';
 
 $lang['notsavedyet'] = 'Unsaved changes will be lost.\nReally continue?';
-$lang['rssfailed']   = 'An error occured while fetching this feed: ';
+$lang['rssfailed']   = 'An error occurred while fetching this feed: ';
 $lang['nothingfound']= 'Nothing was found.';
 
 $lang['mediaselect'] = 'Media Files';
@@ -225,7 +225,7 @@ $lang['i_badhash']    = 'unrecognised or modified dokuwiki.php (hash=<code>%s</c
 $lang['i_badval']     = '<code>%s</code> - illegal or empty value';
 $lang['i_success']    = 'The configuration was finished successfully. You may delete the install.php file now. Continue to
                         <a href="doku.php">your new DokuWiki</a>.';
-$lang['i_failure']    = 'Some errors occured while writing the configuration files. You may need to fix them manually before
+$lang['i_failure']    = 'Some errors occurred while writing the configuration files. You may need to fix them manually before
                          you can use <a href="doku.php">your new DokuWiki</a>.';
 $lang['i_policy']     = 'Initial ACL policy';
 $lang['i_pol0']       = 'Open Wiki (read, write, upload for everyone)';
diff --git a/lib/exe/spellcheck.php b/lib/exe/spellcheck.php
index aa1168136a2208026fbfde12611f60298f8f1082..e4739b60c8a6b3becfa5ae75cbe74995cecbcc1e 100644
--- a/lib/exe/spellcheck.php
+++ b/lib/exe/spellcheck.php
@@ -104,7 +104,7 @@ function spaceslink($matches){
  *
  * 0 - No spelling mistakes
  * 1 - Spelling mistakes found
  * 2 - An error occured error message follows
  *
  * @author Andreas Gohr <andi@splitbrain.org>
  */
@@ -131,7 +131,7 @@ function spell_check() {
   // run aspell in terse sgml mode, ignore nbsp as correct word
   if(!$spell->runAspell($string,$out,$err,array('!','+html','@nbsp'))){
     print '2'; //to indicate an error
-    print "An error occured while trying to run the spellchecker:\n";
+    print "An error occurred while trying to run the spellchecker:\n";
     print $err;
     return;
   }
@@ -104,7 +104,7 @@ function spaceslink($matches){
  * 0 - No spelling mistakes
  * 1 - Spelling mistakes found
- * 2 - An error occured error message follows
+ * 2 - An error occurred error message follows
  *
  * @author Andreas Gohr <andi@splitbrain.org>